@@ -139,7 +139,7 @@ void test_boolean()
     test_assert( "boolean true pybool var ", pb1 ? true : false, true );
 
     b1 = pb1;
-    test_assert( "boolean true bool = pybool", pb1 ? true : false, true );
+    test_assert( "boolean true bool = pybool", b1, true );
 
     pb2 = pb1;
     test_assert( "boolean true pybool = pybool", pb2 ? true : false, true );
@@ -157,7 +157,7 @@ void test_boolean()
     test_assert( "boolean false pybool var ", pb1 ? true : false, false );
 
     b1 = pb1;
-    test_assert( "boolean false bool = pybool", pb1 ? true : false, false );
+    test_assert( "boolean false bool = pybool", b1, false );
 
     pb2 = pb1;
     test_assert( "boolean false pybool = pybool", pb2 ? true : false, false );
@@ -406,7 +406,7 @@ void test_List()
     Py::List list1;
     Py::List list2;
 
-    test_assert( "list empty len()", list1.size(), static_cast<size_t>( 0 ) );
+    test_assert( "list empty len()", list1.size(), static_cast<Py_ssize_t>( 0 ) );
 
     list2.append( Py::String( "list2 index 0" ) );
     list2.append( Py::String( "list2 index 1" ) );
@@ -416,7 +416,7 @@ void test_List()
     list1.append( list2 );
     list1.append( Py::String( "world" ) );
 
-    test_assert( "list len()", static_cast<size_t>( 4 ), list1.size() );
+    test_assert( "list len()", static_cast<Py_ssize_t>( 4 ), list1.size() );
 
     test_assert( "list index[0]", Py::Long( 3 ), list1[0] );
     test_assert( "list index[1]", Py::Float( 6.0 ), list1[1] );
@@ -448,7 +448,7 @@ void test_List()
 
     Py::List list3;
     list3 = list1 + list2;
-    test_assert( "list operator+ count", static_cast<size_t>( 6 ), list3.size() );
+    test_assert( "list operator+ count", static_cast<Py_ssize_t>( 6 ), list3.size() );
 
     Py::Tuple tuple1( list1 );
     test_assert( "list construct from tuple", list1.size(), tuple1.size() );
@@ -488,7 +488,7 @@ void test_Tuple()
     {
         tuple3[0] = Py::Long( 1 ); // should fail, tuple has multiple references
     }
-    catch( Py::Exception &e )
+    catch( Py::BaseException &e )
     {
         e.clear();
         test_passed = true;
@@ -545,8 +545,8 @@ void test_Dict()
     test_assert( "dict index[std::string]", dict1[ std::string("one") ], Py::Long( 1 ) );
     test_assert( "dict index[Py::String]", dict1[ str1 ], Py::Long( 2 ) );
 
-    test_assert( "dict keys()", dict1.keys().size(), static_cast<size_t>( 3 ) );
-    test_assert( "dict values()", dict1.values().size(), static_cast<size_t>( 3 ) );
+    test_assert( "dict keys()", dict1.keys().size(), static_cast<Py_ssize_t>( 3 ) );
+    test_assert( "dict values()", dict1.values().size(), static_cast<Py_ssize_t>( 3 ) );
 
     Py::Dict::iterator it1 = dict1.begin();
     test_assert( "dict iterator not end != [0]", true, it1 != dict1.end() );
@@ -575,7 +575,7 @@ void test_Dict()
 
     Py::Dict dict2 = dict1;
     dict2.clear();
-    test_assert( "dict clear()", dict2.keys().length(), static_cast<size_t>( 0 ) );
+    test_assert( "dict clear()", dict2.keys().length(), Py_ssize_t( 0 ) );
 
     const Py::Dict c;
     for (Py::Dict::const_iterator it = c.begin(); it != c.end(); ++it)
@@ -750,7 +750,7 @@ private:
             a.verify_length(0);
             std::cout << "I see that you refuse to give me any work to do." << std::endl;
         }
-        catch (Py::Exception& e)
+        catch (Py::BaseException& e)
         {
             e.clear();
             std::cout << "I will now add up your elements, oh great one." << std::endl;
@@ -767,7 +767,7 @@ private:
         return f;
     }
 
-    Py::Object ex_test( const Py::Tuple &args )
+    Py::Object ex_test( const Py::Tuple &/*args*/ )
     {
         debug_check_ref_queue();
 
@@ -784,8 +784,8 @@ private:
             e.clear();
 
             std::cout << "PASSED: Correctly caught " << Py::type(e) << std::endl;
-            std::cout << "PASSED:   Py::Exception value: " << Py::value(e) << std::endl;
-            std::cout << "PASSED:   Py::Exception traceback: " << Py::trace(e) << std::endl;
+            std::cout << "PASSED:   Py::BaseException value: " << Py::value(e) << std::endl;
+            std::cout << "PASSED:   Py::BaseException traceback: " << Py::trace(e) << std::endl;
         }
 
         try
